@@ -32,18 +32,7 @@ class IAddTag(Interface):
                      description=_(u"Position in the Y axis of the center of the box (0-100%)"),
                      min=0.0,
                      max=100.0)
-
-    # Required to replace JavaScript dot decimal separator with server expected decimal separator
-    decimal = schema.Text(title=_(u"Decimal digit"))
                      
-class IAddAjaxTag(Interface):
-    """
-    Fields for ajax-submitted form
-    """
-    ajax = schema.Int(title=u"Ajax submitted",
-                      default=1,
-                      required=False)
-
 class IImageTagsHelper(Interface):
     """
     imagetags-helper interface with helper methods for manage and image browser views
