@@ -2,20 +2,21 @@
 
 jQuery(document).ready(function() {
     if(jQuery('.tag-image-wrapper').length) {
-        // Load ajax form
-        jQuery('body').append('<div id="ajax-form" style="display: none; "></div>');
-        jQuery('#ajax-form').load(ImageTags.contextUrl().replace('@@imagetags-manage', '@@imagetags-form-ajax'));
+        // Mark management screen as inline managing
         jQuery('.tag-manage').removeClass('tag-manage').addClass('tag-manage-inline');
-        jQuery('#imagetags-form, #imagetags-manage').hide();
+        // Hide table of tags management; 'Tag details' fieldset; and ajax-form div, containing the very form
+        jQuery('#imagetags-manage, #imagetags-form, #ajax-form').hide();
+        // Hide x, y fields
+        jQuery('#form-widgets-x, #form-widgets-y').each(function(idx, el) {
+            jQuery(el).closest('div.field').hide();
+        });
         jQuery('#tag-start-tagging').show().click(ImageTags.startTagging);
         jQuery('#tag-stop-tagging').click(ImageTags.stopTagging);
         // Remove unload protection from forms (taken from formUnload.js)
-        /* Waiting for bug fix in formUnload.js to enable this
         var tool = window.onbeforeunload && window.onbeforeunload.tool;
         if (tool) {
             tool.removeForms.apply(tool, jQuery('form.enableUnloadProtection').get());
         }
-        */
         // auto-select input fields
         jQuery('.tag-embed-code input').focus(function(event) {event.target.select();});
         ImageTags.prepareEmbedOptions();
@@ -52,8 +53,8 @@ ImageTags = {
         var formContainer = jQuery('#ajax-form');
         var form = formContainer.find('form');
         form.submit(ImageTags.submitForm);
-        // Add onblur event to required fields (span.required is sibling of div.widget with input children)
-        form.find('.fieldRequired').next().find('input').keyup(ImageTags.checkRequired);
+        // Add onblur event to required fields
+        form.find('input.required').keyup(ImageTags.checkRequired);
         // Add a special tag-tagging class and bind click event on the wrapper
         jQuery('.tag-image-wrapper').addClass('tag-tagging').click(ImageTags.onWrapperClick);
         // Turns boxes (a.tag-link) into draggable, bind the stop event and add a special class to them
@@ -75,7 +76,7 @@ ImageTags = {
         // Hide save button and allow multi submit
         form.find('input.submit-widget').hide().addClass('allowMultiSubmit');
         // Get decimal separator
-        ImageTags.separator = jQuery('#form-widgets-decimal').attr('value');
+        //ImageTags.separator = jQuery('#form-widgets-decimal').attr('value');
     },
     
     
@@ -340,13 +341,6 @@ ImageTags = {
         /* Display the edit tag details form
          */
         var formContainer = jQuery('#ajax-form');
-        // onclose function
-        var onclose = function(event, ui) {
-            ImageTags.resetForm();
-            if(box) {
-                box.removeClass('tag-link-active');
-            }
-        };
         // Display the form dialog
         buttons = {};
         buttons[ImageTagsLabels.saveButtonText] = ImageTags.submitForm;
@@ -354,12 +348,20 @@ ImageTags = {
         formContainer.dialog({
             title: ImageTagsLabels.tagFormTitle, 
             resizable: false,
-            close: onclose,
             open: function(event, ui) {
                 jQuery(this).find('input[type!=hidden]:first').focus();
             },
             buttons: buttons
         });
+        // onclose function. It gets the box as extra data to remove a css class name
+        var onclose = function(event, ui) {
+            ImageTags.resetForm();
+            if(event.data && event.data[0]) {
+                var box = jQuery(event.data[0]);
+                box.removeClass('tag-link-active');
+            }
+        };
+        formContainer.bind('dialogclose', box, onclose);
         formContainer.dialog('open');
         
     },
@@ -386,7 +388,7 @@ ImageTags = {
         var button = form.find('input[type=submit]')[0];
         
         // Post data to the server
-        jQuery.post(form.attr('action'), form.serialize() + '&' + button.name + '=' + button.value, onPostSuccess);
+        jQuery.post(form.attr('action'), form.serialize() + '&ajax:int=1&' + button.name + '=' + button.value, onPostSuccess);
     },
     
     resetForm: function() {
@@ -460,7 +462,7 @@ ImageTags = {
     
     replaceDecimalSeparator: function(number) {
         // Replace JavaScript number decimal separator with server expected decimal separator
-        var separator = ImageTags.separator;
+        var separator = ImageTagsLabels.decimalSeparator;
         if(separator!='.') {
             return number.toString().replace('.', separator);
         } else {
